package senhales;

/**
 * Instrumento de medida del laboratorio.
 * 
 * @author Metodos de Programacion (UC)
 * @version mar-2015
 */
public class Instrumento
{
	/**
	 * Frecuencia con la que muestrea el instrumento
	 */
	static public final int frecuenciaMuestreo=100; // muestras por segundo

	/**
	 * Retorna un array de medidas en el intervalo indicado.
	 * 
	 * @param duracion duracion del intervalo durante el que se desean obtener las medidas.
	 * @return array de medidas en el intervalo indicado.
	 */
	static public Medida[] generaSenal(double duracion){
		// Este metodo simula la existencia de un instrumento real de medida
		int nMedidas= (int)(frecuenciaMuestreo*duracion);
		double A=2.5;
		double periodo=10;
		double fase=Math.PI/6; 
		double factorRuido=0.05;

		Medida[] senal= new Medida[nMedidas];
		for (int i=0; i<nMedidas;i++){
			senal[i]=new Medida();
			double t=duracion/nMedidas*i;
			senal[i].t=t;
			senal[i].valor=A*Math.sin(2*Math.PI*t/periodo-fase)+A*(Math.random()-0.5)*factorRuido;
		}
		return senal;
	}

	/**
	 * Realiza el filtrado de las medidas, sustituyendo cada medida por la media de
	 * los valores anterior y posterior en el array.
	 * Los valores primero y último se dejarán como estaban.
	 * 
	 * @param senal senhal que se desea filtrar.
	 * @return array de medidas filtrado.
	 */
	static public Medida[] filtraSenal(Medida[] senal){
		// TODO
	}

	/**
	 * Hace nVeces llamadas al método filtraSenal para que el filtrado sea apreciable
	 * (por ejemplo, con nVeces=100).
	 * 
	 * @param senal senhal que se desea filtrar.
	 * @param nVeces numero de veces que se llama al metodo filtraSenal.
	 * @return array de medidas filtrado.
	 * @see #filtraSenal(Medida[])
	 */
	static public Medida[] filtraSenal(Medida[] senal, int nVeces){
		// TODO
	}

}
